@@ -962,7 +962,7 @@ class StandardFunction:
     @staticmethod
     def rotate_2d(point_coord: pint.Quantity, origin_coord: pint.Quantity, angle: pint.Quantity, direction: str = "x"):
         """
-        calculates the desired the rotated point coordinates around the origin, transformed back to the origin
+        calculates the desired direction of the point coordinates around the origin, transformed back to the origin
 
         Args:
             point_coord: pint.Quantity
@@ -1002,13 +1002,34 @@ class StandardFunction:
 
         return point_shifted_to_init_pos[idx_direction, :]
 
+    @staticmethod
+    def mean_and_rotate_2d(point_coord_x: pint.Quantity, point_coord_y: pint.Quantity, origin_coord: pint.Quantity,
+                           angle: pint.Quantity, direction: str = "x"):
+        """
+
+        Args:
+         point_coord_x:
+         point_coord_y:
+         origin_coord:
+         angle:
+         direction:
+
+         Returns:
+        """
+
+        point_coord = np.vstack((np.mean(point_coord_x, axis=1), np.mean(point_coord_y, axis=1))).T
+        return StandardFunction.rotate_2d(point_coord=point_coord, origin_coord=origin_coord,
+                                          angle=angle, direction=direction)
+
     @staticmethod
     def osccar_rib_criteria(object_data: dict, nr_largest_elements: int, age: float, risk_curve):
         """
 
         Args:
-          object_data: param nr_largest_elements:
-          age: param risk_curve:
+          object_data:
+          nr_largest_elements:
+          age:
+          risk_curve:
         
         :return histogram probability broken ribs:
           object_data: dict: 
