@@ -67,8 +67,13 @@ class BinoutData(object):
         """
         defined_ids = self._dynasaur_definitions.get_object_ids_from_object_name(object_name, self._name)
         available_ids = self.get_ids()
-        channel_ids = np.intersect1d(defined_ids, available_ids)
-
+        # NOTE:
+        # using np.intersect1d
+        # causes problems if the dynasaur Object contains the same id multiple times. i.e. defined_ids = [100, 100]
+        # channel_ids = np.intersect1d(defined_ids, available_ids).
+        # order of defined_ids should be kept as well
+        #
+        channel_ids = [defined_id for defined_id in defined_ids if defined_id in available_ids]
         return channel_ids
 
     def get_ids(self):
@@ -448,6 +453,7 @@ class BinoutData(object):
         t = self._dynasaur_definitions.get_units().time
         m = self._dynasaur_definitions.get_units().mass
         l = self._dynasaur_definitions.get_units().length
+        angle = self._dynasaur_definitions.get_units().angle
 
         force = m * l / (t**2)
         moment = force * l
@@ -455,8 +461,9 @@ class BinoutData(object):
         area = l**2
         acceleration = l/(t**2)
         velocity = l/t
-        r_velocity = 1/t
-        r_acceleration = 1/(t**2)
+
+        r_velocity = angle/t
+        r_acceleration = angle/(t**2)
 
         if "forc" in channel_name or "axial" in channel_name or "radial" in channel_name:
             return force
@@ -486,7 +493,7 @@ class BinoutData(object):
 
         # mind order of if
         elif "rx_displacement" in channel_name or "ry_displacement" in channel_name or "rz_displacement" in channel_name:
-            return dim_less
+            return angle
 
         elif "displacement" in channel_name:
             return l
