@@ -239,12 +239,16 @@ class DataVisualizationController(PluginInterface, Plugin):
             for visualization in d[part_of].keys():
                 if len(d[part_of][visualization]["X"]) < length or len(d[part_of][visualization]["Y"]) < length:
                     index_x = len(d[part_of][visualization]["X"])
-                    d[part_of][visualization]["X"] = np.concatenate(
-                        (d[part_of][visualization]["X"], [None] * (length - index_x)))
+                    padding_x = [None] * (length - index_x)
+                    if isinstance(d[part_of][visualization]["X"], pint.Quantity):
+                        padding_x *= d[part_of][visualization]["X"].units
+                    d[part_of][visualization]["X"] = np.concatenate((d[part_of][visualization]["X"], padding_x))
 
                     index_y = len(d[part_of][visualization]["Y"])
-                    d[part_of][visualization]["Y"] = np.concatenate(
-                            (d[part_of][visualization]["Y"], [None] * (length - index_y)))
+                    padding_y = [None] * (length - index_y)
+                    if isinstance(d[part_of][visualization]["X"], pint.Quantity):
+                        padding_y *= d[part_of][visualization]["X"].units
+                    d[part_of][visualization]["Y"] = np.concatenate((d[part_of][visualization]["Y"], padding_y))
         return d
 
     @staticmethod
